@@ -3,6 +3,8 @@
 import datetime
 import logging
 
+from django.utils import timezone
+
 from django_filters.filters import (
     AllValuesFilter,
     AllValuesMultipleFilter,
@@ -17,6 +19,7 @@ from django_filters.filters import (
     DurationFilter,
     IsoDateTimeFilter,
     IsoDateTimeFromToRangeFilter,
+    LookupChoiceFilter,
     MultipleChoiceFilter,
     NumberFilter,
     RangeFilter,
@@ -52,13 +55,21 @@ class PropertyBaseFilterMixin():
         self.property_fld_name = kwargs.get('field_name')
         kwargs['field_name'] = None
 
+        # Set the default lookup if none is specified
+        if lookup_expr is None:
+            lookup_expr = self.supported_lookups[0]
+            kwargs['lookup_expr'] = lookup_expr
+
+        # Set the Label
         if label is None:
             label = F'{self.property_fld_name} [{lookup_expr}]'
             kwargs['label'] = label
 
-        self.verify_lookup(lookup_expr)
         super().__init__(*args, **kwargs)
 
+        # Verify lookup after initializing since django-filter can set it as well
+        self.verify_lookup(lookup_expr)
+
     def filter(self, queryset, value):
         """Filter the queryset by property."""
         # Carefull, a filter value of 0 will be Valid so can't just do 'if value:'
@@ -80,6 +91,11 @@ class PropertyBaseFilterMixin():
     def _compare_lookup_with_qs_entry(self, lookup_expr, lookup_value, property_value):  # pylint: disable=no-self-use
         """Compare the lookup value with the property value."""
         result = False
+
+        # Convert any of the Lookups, e.g. for Range with only 1 value
+        lookup_expr, lookup_value, property_value = self._lookup_convertion(
+            lookup_expr, lookup_value, property_value)
+
         try:
             result = compare_by_lookup_expression(lookup_expr, lookup_value, property_value)
         except (TypeError) as error:
@@ -88,6 +104,9 @@ class PropertyBaseFilterMixin():
 
         return result
 
+    def _lookup_convertion(self, lookup_expr, lookup_value, property_value):  # pylint: disable=no-self-use
+        return lookup_expr, lookup_value, property_value
+
 
 class ChoiceConvertionMixin():  # pylint: disable=too-few-public-methods
     """Provide Comparison Convertion for Choice Filters."""
@@ -141,6 +160,22 @@ class MultipleChoiceFilterMixin():  # pylint: disable=too-few-public-methods
         return result_qs if result_qs is not None else self.model.objects.none()
 
 
+class RangeFilterFilteringMixin():  # pylint: disable=too-few-public-methods
+    """Provide filtering for Range Filters."""
+
+    def _lookup_convertion(self, lookup_expr, lookup_value, property_value):  # pylint: disable=no-self-use
+
+        if lookup_expr == 'range':
+            if lookup_value.start is None:
+                lookup_expr = 'lte'
+                lookup_value = lookup_value.stop
+            elif lookup_value.stop is None:
+                lookup_expr = 'gte'
+                lookup_value = lookup_value.start
+
+        return lookup_expr, lookup_value, property_value
+
+
 class PropertyAllValuesFilter(ChoiceConvertionMixin, PropertyBaseFilterMixin, AllValuesFilter):
     """Adding Property Support to AllValuesFilter."""
 
@@ -201,10 +236,10 @@ class PropertyChoiceFilter(ChoiceConvertionMixin, PropertyBaseFilterMixin, Choic
 class PropertyDateFilter(PropertyBaseFilterMixin, DateFilter):
     """Adding Property Support to DateFilter."""
 
-    supported_lookups = ['exact', 'iexact', 'gt', 'gte', 'lt', 'lte']
+    supported_lookups = ['exact', 'gt', 'gte', 'lt', 'lte']
 
 
-class PropertyDateFromToRangeFilter(PropertyBaseFilterMixin, DateFromToRangeFilter):
+class PropertyDateFromToRangeFilter(RangeFilterFilteringMixin, PropertyBaseFilterMixin, DateFromToRangeFilter):
     """Adding Property Support to DateFromToRangeFilter."""
 
     supported_lookups = ['range']
@@ -248,23 +283,25 @@ class PropertyDateRangeFilter(PropertyBaseFilterMixin, DateRangeFilter):
             new_property_value = property_value.date()
 
         # Convert our Custom Expression and Value to Supported the Hardcoded Expressions
+        today_datetime = timezone.now()
+
         if lookup_value == 'today':
-            new_lookup_value = datetime.date.today()
+            new_lookup_value = today_datetime.date()
         elif lookup_value == 'yesterday':
-            new_lookup_value = datetime.date.today() - datetime.timedelta(days=1)
+            new_lookup_value = today_datetime.date() - datetime.timedelta(days=1)
         elif lookup_value == 'week':
             new_lookup_exp = 'range'
             new_lookup_value = slice(
-                datetime.date.today() - datetime.timedelta(days=7),
-                datetime.date.today()
+                today_datetime.date() - datetime.timedelta(days=7),
+                today_datetime.date()
             )
         elif lookup_value == 'month':
             new_lookup_exp = 'exact'
-            new_lookup_value = datetime.date.today().month
+            new_lookup_value = today_datetime.date().month
             new_property_value = property_value.month
         elif lookup_value == 'year':
             new_lookup_exp = 'exact'
-            new_lookup_value = datetime.date.today().year
+            new_lookup_value = today_datetime.date().year
             new_property_value = property_value.year
 
         return super()._compare_lookup_with_qs_entry(new_lookup_exp, new_lookup_value, new_property_value)
@@ -276,7 +313,7 @@ class PropertyDateTimeFilter(PropertyBaseFilterMixin, DateTimeFilter):
     supported_lookups = ['exact', 'gt', 'gte', 'lt', 'lte']
 
 
-class PropertyDateTimeFromToRangeFilter(PropertyBaseFilterMixin, DateTimeFromToRangeFilter):
+class PropertyDateTimeFromToRangeFilter(RangeFilterFilteringMixin, PropertyBaseFilterMixin, DateTimeFromToRangeFilter):
     """Adding Property Support to DateTimeFromToRangeFilter."""
 
     supported_lookups = ['range']
@@ -294,12 +331,38 @@ class PropertyIsoDateTimeFilter(PropertyBaseFilterMixin, IsoDateTimeFilter):
     supported_lookups = ['exact', 'gt', 'gte', 'lt', 'lte']
 
 
-class PropertyIsoDateTimeFromToRangeFilter(PropertyBaseFilterMixin, IsoDateTimeFromToRangeFilter):
+class PropertyIsoDateTimeFromToRangeFilter(
+        RangeFilterFilteringMixin, PropertyBaseFilterMixin, IsoDateTimeFromToRangeFilter):
     """Adding Property Support to IsoDateTimeFromToRangeFilter."""
 
     supported_lookups = ['range']
 
 
+class PropertyLookupChoiceFilter(ChoiceConvertionMixin, PropertyBaseFilterMixin, LookupChoiceFilter):
+    """Adding Property Support to LookupChoiceFilter."""
+
+    def get_lookup_choices(self):
+        """Get th Lookup choices in the correct format."""
+        lookups = self.lookup_choices
+        if lookups is None:
+            lookups = self.supported_lookups
+
+        lookup_tup_list = [self.normalize_lookup(lookup) for lookup in lookups]
+
+        for lookup_expr, _ in lookup_tup_list:
+            self.verify_lookup(lookup_expr)
+
+        return lookup_tup_list
+
+    def filter(self, queryset, value):
+        """Perform the custom filtering."""
+        if not value:
+            return super().filter(queryset, None)
+
+        self.lookup_expr = value.lookup_expr
+        return super().filter(queryset, value.value)
+
+
 class PropertyMultipleChoiceFilter(
         ChoiceConvertionMixin, MultipleChoiceFilterMixin, PropertyBaseFilterMixin, MultipleChoiceFilter):
     """Adding Property Support to MultipleChoiceFilter."""
@@ -308,8 +371,11 @@ class PropertyMultipleChoiceFilter(
 class PropertyNumberFilter(PropertyBaseFilterMixin, NumberFilter):
     """Adding Property Support to NumberFilter."""
 
+    supported_lookups = [
+        'exact', 'contains', 'gt', 'gte', 'lt', 'lte', 'startswith', 'endswith']
 
-class PropertyRangeFilter(PropertyBaseFilterMixin, RangeFilter):
+
+class PropertyRangeFilter(RangeFilterFilteringMixin, PropertyBaseFilterMixin, RangeFilter):
     """Adding Property Support to RangeFilter."""
 
     supported_lookups = ['range']
@@ -318,10 +384,10 @@ class PropertyRangeFilter(PropertyBaseFilterMixin, RangeFilter):
 class PropertyTimeFilter(PropertyBaseFilterMixin, TimeFilter):
     """Adding Property Support to TimeFilter."""
 
-    supported_lookups = ['exact', 'iexact', 'gt', 'gte', 'lt', 'lte']
+    supported_lookups = ['exact', 'gt', 'gte', 'lt', 'lte']
 
 
-class PropertyTimeRangeFilter(PropertyBaseFilterMixin, TimeRangeFilter):
+class PropertyTimeRangeFilter(RangeFilterFilteringMixin, PropertyBaseFilterMixin, TimeRangeFilter):
     """Adding Property Support to TimeRangeFilter."""
 
     supported_lookups = ['range']
@@ -344,7 +410,8 @@ class PropertyUUIDFilter(PropertyBaseFilterMixin, UUIDFilter):
 
 EXPLICIT_ONLY_FILTERS = [
     PropertyChoiceFilter,
+    PropertyLookupChoiceFilter,
+    PropertyMultipleChoiceFilter,
     PropertyTypedChoiceFilter,
     PropertyTypedMultipleChoiceFilter,
-    PropertyMultipleChoiceFilter,
 ]
